package com.ruoyi.system.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.ActSupplies;
import com.ruoyi.system.service.IActSuppliesService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * 物料总分类管理Controller
 *
 * @author ruoyi
 * @date 2023-07-11
 */
@RestController
@RequestMapping("/Actsupplies/Actsupplies")
public class ActSuppliesController extends BaseController
{
    @Autowired
    private IActSuppliesService actSuppliesService;


    @PreAuthorize("@ss.hasPermi('Actsupplies:Actsupplies:options')")
    @GetMapping("/options")
    @ResponseBody
    public TableDataInfo options(){

        List<ActSupplies> options = actSuppliesService.options();

        return getDataTable(options);

    }


    /**
     * 查询物料总分类管理列表
     */
    @PreAuthorize("@ss.hasPermi('Actsupplies:Actsupplies:list')")
    @GetMapping("/list")
    public TableDataInfo list(ActSupplies actSupplies)
    {
        startPage();
        List<ActSupplies> list = actSuppliesService.selectActSuppliesList(actSupplies);;
        return getDataTable(list);
    }

    /**
     * 查询物料总分类管理列表
     */
    @PreAuthorize("@ss.hasPermi('Actsupplies:Actsupplies:listOne')")
    @GetMapping("/listOne")
    public TableDataInfo listOne(ActSupplies actSupplies)
    {
        startPage();
        List<ActSupplies> list = actSuppliesService.selectActSuppliesListOne(actSupplies);;
        return getDataTable(list);
    }



    /**
     * 导出物料总分类管理列表
     */
    @PreAuthorize("@ss.hasPermi('Actsupplies:Actsupplies:export')")
    @Log(title = "物料总分类管理", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(ActSupplies actSupplies)
    {
        List<ActSupplies> list = actSuppliesService.selectActSuppliesList(actSupplies);
        ExcelUtil<ActSupplies> util = new ExcelUtil<ActSupplies>(ActSupplies.class);
        return util.exportExcel(list, "物料总分类管理数据");
    }

    /**
     * 导出物料总分类管理列表
     */
    @PreAuthorize("@ss.hasPermi('Actsupplies:Actsupplies:exportOne')")
    @Log(title = "物料总分类管理", businessType = BusinessType.EXPORT)
    @GetMapping("/exportOne")
    public AjaxResult exportOne(ActSupplies actSupplies)
    {
        List<ActSupplies> list = actSuppliesService.selectActSuppliesListOne(actSupplies);
        ExcelUtil<ActSupplies> util = new ExcelUtil<ActSupplies>(ActSupplies.class);
        return util.exportExcel(list, "物料总分类管理数据");
    }

    /**
     * 获取物料总分类管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('Actsupplies:Actsupplies:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(actSuppliesService.selectActSuppliesById(id));
    }

    /**
     * 新增物料总分类管理
     */
    @PreAuthorize("@ss.hasPermi('Actsupplies:Actsupplies:add')")
    @Log(title = "物料总分类管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ActSupplies actSupplies)
    {
        SysUser user = SecurityUtils.getLoginUser().getUser();
        actSupplies.setCreateBy(user.getUserName());
        /*return toAjax(actSuppliesService.insertActSupplies(actSupplies));*/
        int i = actSuppliesService.insertActSupplies(actSupplies);
        if(i==0){
            return AjaxResult.error("添加名称失败，名称已被占用");
        }
        return  AjaxResult.success("添加成功");
    }

    /**
     * 修改物料总分类管理
     */
    @PreAuthorize("@ss.hasPermi('Actsupplies:Actsupplies:edit')")
    @Log(title = "物料总分类管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ActSupplies actSupplies)
    {
        SysUser user = SecurityUtils.getLoginUser().getUser();
        actSupplies.setUpdateBy(user.getUserName());
//        return toAjax(actSuppliesService.updateActSupplies(actSupplies));
        int i = actSuppliesService.updateActSupplies(actSupplies);
        if(i==0){
            return AjaxResult.error("修改名称失败.名称已被占用");
        }
        return AjaxResult.success("修改成功");
    }

    /**
     * 删除物料总分类管理
     */
    @PreAuthorize("@ss.hasPermi('Actsupplies:Actsupplies:remove')")
    @Log(title = "物料总分类管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {

        if (actSuppliesService.findall(ids).size()>0 || actSuppliesService.findAllId(ids).size()>0){

            return AjaxResult.error("该物料下存在关联物料，请先删除关联物料！！！","操作失败");

        }

        return toAjax(actSuppliesService.deleteActSuppliesByIds(ids));
    }
    /**
     * 启用物料总分类管理
     */
    @PreAuthorize("@ss.hasPermi('Actsupplies:Actsupplies:enable')")
    @GetMapping("/enable/{id}")
    public AjaxResult setEnable(@PathVariable("id") Long id)
    {
        System.out.println("开始处理【启用物料总分类管理】的请求，参数：{}"+ id);
        actSuppliesService.setEnable(id);
        return AjaxResult.success();
    }

    /**
     * 禁用物料总分类管理
     */
    @PreAuthorize("@ss.hasPermi('Actsupplies:Actsupplies:Disable')")
    @GetMapping("/disable/{id}")
    public AjaxResult setDisable(@PathVariable("id") Long id)
    {

        if (actSuppliesService.find(id).size()>0 || actSuppliesService.findId(id).size()>0){

            return AjaxResult.success("该物料下存在关联物料，请先删除关联物料！！！","操作失败");

        }

        System.out.println("开始处理【禁用物料总分类管理】的请求，参数：{}"+ id);
        actSuppliesService.setDisable(id);

        return AjaxResult.success("200","修改成功");

    }


}
